autowisp.pipeline_exceptions module — AutoWISP documentation

# autowisp.pipeline_exceptions module

## Class Inheritance Diagram

Collection of non-standard exceptions raised by the pipeline.

exception autowisp.pipeline_exceptions.BadImageError

  Bases: `ValueError`

  An image does not look like it is expected to.

exception autowisp.pipeline_exceptions.ConvergenceError

  Bases: `RuntimeError`

  Some iterative procedure failed to converge.

exception autowisp.pipeline_exceptions.HDF5LayoutError

  Bases: `RuntimeError`

  Error caused by invalid specification of HDF5 layout.

exception autowisp.pipeline_exceptions.ImageMismatchError

  Bases: `ValueError`

  Attempt to combine incompatible images in some way.

exception autowisp.pipeline_exceptions.OutsideImageError

  Bases: `IndexError`

  Attempt to access image data outside the bounds of the image.